package front

import (
	"notabug.org/apiote/amuse/tmdb"

	"golang.org/x/text/language"
)

func TODO(message string) interface{} {
	panic(message)
}

type CapnprotoRenderer struct{}

func (CapnprotoRenderer) RenderFilm(film *tmdb.Film, languages []language.Tag) string {
	return TODO("implement CapnprotoRenderer.RenderFilm").(string)
}

func (CapnprotoRenderer) RenderSearch(results *tmdb.SearchResults, languages []language.Tag) string {
	return TODO("implement CapnprotoRenderer.RenderSearch").(string)
}

func (CapnprotoRenderer) RenderIndex(randomComedy string, languages []language.Tag) string {
	return TODO("implement CapnprotoRenderer.RenderIndex").(string)
}

func (CapnprotoRenderer) RenderSerie(serie *tmdb.Serie, languages []language.Tag) string {
	return TODO("implement CapnprotoRenderer.RenderSerie").(string)
}

func (CapnprotoRenderer) RenderPerson(person *tmdb.Person, languages []language.Tag) string {
	return TODO("implement CapnprotoRenderer.RenderPerson").(string)
}

func (CapnprotoRenderer) RenderAbout(languages []language.Tag) string {
	return TODO("implement CapnprotoRenderer.RenderAbout").(string)
}

func (CapnprotoRenderer) RenderErrorPage(code int, languages []language.Tag) string {
	return TODO("implement CapnprotoRenderer.RenderErrorPage").(string)
}
